﻿/* -----------------------------------------------------------------------------------------------------
 * Recherche.cs
 * Gère l'obtention du video , la gestion du ROI et l'appel de graphique
 *  -----------------------------------------------------------------------------------------------------*/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Emgu.CV.Structure;
using Emgu.CV;
using Emgu.CV.UI;
using System.Threading;
using TP.Properties;
using FlyCapture2Managed;
using System.IO;
using System.Linq;
using System.Management;


namespace TP
{
	public partial class SystemeDetection : Form
	{
		Image<Bgr, Byte> matrice; // image de la matrice
		Image<Bgr, Byte> imageInitiale; // image de la matrice
		private int increment = 0, maxIncrement = 6000; // increment servant a la fonction thread pour l'attente
		List<typeGraine> listeGraine = new List<typeGraine>();
		private string nomAttente = ""; // Message d'attente du thread
		ParamThread pt = new ParamThread();

		/* -----------------------------------------------------------------------------------------------------
		 *  Initialise le programme 
		 *  -----------------------------------------------------------------------------------------------------*/
		public SystemeDetection()
		{
			InitializeComponent();

			ValX.Value = Settings.Default.gauche;
			ValH.Value = Settings.Default.droit;
			ValY.Value = Settings.Default.haut;
			ValW.Value = Settings.Default.bas;
			HMinG.Value = Settings.Default.hauteurMinGraine;
			HMaxG.Value = Settings.Default.hauteurMaxGraine;
			LMinG.Value = Settings.Default.largeurMinGraine;
			LMaxG.Value = Settings.Default.largeurMaxGraine;
			pt.changerRinit((int)ValX.Value, (int)ValY.Value, (int)ValH.Value, (int)ValW.Value); // inverser ValH et ValW ?????????????
    /*        SP1.PortName = GetPortByDeviceID("FTDIBUS\\VID_0403+PID_6001+A601LO4XA\\0000");

            // Portname devrait etre COM3
			
			 if(SP1.PortName == "null" || String.IsNullOrEmpty(SP1.PortName))
			 {
			       MessageBox.Show("Impossible d'établir la communication avec la carte d'illumination.\nFin prématurée du programme.",
								    "Erreur !",
			 						MessageBoxButtons.OK,
			 						MessageBoxIcon.Exclamation,
			 						MessageBoxDefaultButton.Button1);
			 						
				   Application.Exit();
			  }
			  else
			  {
			       SP1.Open();
                 // ouvrir l'illumination NIR MID (5/10)
                   SP1.Write("O");
				   SP1.Write("I");
				   SP1.Write("5");
			  }*/
			 
		}

		private string GetPortByDeviceID(string deviceId)
		{
			try
			{
				List<ComPort> ports = new List<ComPort>();

				ManagementObjectSearcher moSearcher = new ManagementObjectSearcher("root\\CIMV2", "SELECT * FROM Win32_PnPEntity");

				foreach (ManagementObject queryObj in moSearcher.Get())
				{
					/*recueille seulement les ports COM*/
					if (queryObj["Caption"] != null && queryObj["Caption"].ToString().Contains("(COM"))
					{
						string[] parts = queryObj["Caption"].ToString().Split(new string[] { "(COM" }, StringSplitOptions.None);

						/*Ajoute info à la liste*/
						ports.Add(new ComPort
						{
							Name = parts[0].Remove(parts[0].Length - 1),
							Number = "COM" + parts[1].Remove(parts[1].Length - 1),
							Id = queryObj["DeviceID"].ToString()
						});
					}
				}

				/*Sélectionne le bon port COM*/
				ComPort selected = (from p in ports
									where p.Id == deviceId
									select p).FirstOrDefault();

				if (selected != null)
					return selected.Number;

				else
					return "null";

			}
			catch (ManagementException e)
			{
				return "null";
			}
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Ferme le formulaire
		 *  -----------------------------------------------------------------------------------------------------*/
		private void BouttonAnnuler_Click(object sender, EventArgs e)
		{
            
            // fermer l'illumination NIR MID (5/10)
           /* SP1.Write("F");
            SP1.Write("X");
            SP1.Write("X");
            SP1.Close();*/
			this.Close();
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Initialise le formulaire  à partir d'un fichier video et affiche la première image
		 * -----------------------------------------------------------------------------------------------------*/

		private void bouttonDemarerCameraEMGU_Click(object sender, EventArgs e)
		{
			pictureBox1.Image = null;
			pt.type = listeGraine.Find(delegate(typeGraine g) { return g.nom == comboBoxTypeGraine.SelectedValue.ToString(); });

			accesibiliteButton(false, false, false, true, false, false, false, false);
			if (bwPartirVideo.IsBusy != true) { bwPartirVideo.RunWorkerAsync(pt); }

		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Initialise le formulaire  à partir d'un fichier video et affiche la première image
		 * -----------------------------------------------------------------------------------------------------*/

		private void bouttonDemarerCamera_Click(object sender, EventArgs e)
		{
			pictureBox1.Image = null;
			pt.type = listeGraine.Find(delegate(typeGraine g) { return g.nom == comboBoxTypeGraine.SelectedValue.ToString(); });


			accesibiliteButton(false, true, false, false, false, false, false, false);
			if (bwPartirCam.IsBusy != true) { bwPartirCam.RunWorkerAsync(pt); }
		}



		/* -----------------------------------------------------------------------------------------------------
		 *  Defini les contenant de la matrice
		 * -----------------------------------------------------------------------------------------------------*/
		private List<Recipient> definirContenantTest(Image<Bgr, Byte> _image)
		{
			List<Recipient> listeContenant = new List<Recipient>();
			int nombre = 0;
			matrice = _image.CopyBlank();
			for (int j = 0; j < Settings.Default.hauteurMatrice; j++)
				for (int i = 0; i < Settings.Default.largeurMatrice; i++)
				{
					Rectangle r = new Rectangle(10 + ((matrice.Width / Settings.Default.largeurMatrice) * i), 10 +
								  ((matrice.Height / Settings.Default.hauteurMatrice) * j), (matrice.Width / Settings.Default.largeurMatrice) - 10, (matrice.Height / Settings.Default.hauteurMatrice) - 10);
					listeContenant.Add(new Recipient(r.X, r.Y, r.Width, r.Height,  ++nombre));
					matrice.Draw(r, new Bgr(255, 255, 255), 6);
				}
			_image.Dispose();
			_image = null;

			return listeContenant;
		}

		/* -----------------------------------------------------------------------------------------------------
	*  appel de la fonction assurant la gestion du video
	*  -----------------------------------------------------------------------------------------------------*/
		private void button_gestion_video_Click(object sender, EventArgs e)
		{
			pictureBox1.Image = null;
			pt.type = listeGraine.Find(delegate(typeGraine g) { return g.nom == comboBoxTypeGraine.SelectedValue.ToString(); });
		 
			if (textBoxNomFichier.Text == "")
			{
				MessageBox.Show("Le projet n'a pas de nom!");
				return;
			}
			GrabberEMGU g1 = new GrabberEMGU(textBoxVid.Text); // s'occupe de la gestion des camera
			if (g1.partirCamera())
			{
				Image<Bgr, Byte> im2 = g1.RetourImage();
				imageInitiale = im2;
				im2.ROI = pt.Rinit;
				pt.ListeRecipientMatrice = definirContenantTest(im2.Copy());
				im2.Dispose();
				im2 = null;
				g1.arreterCamera();
			}
			accesibiliteButton(false, false, false, false, false, false, false, true);
			if (bwEMGU.IsBusy != true) { bwEMGU.RunWorkerAsync(pt); }
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  appel de la fonction assurant la gestion de la camera
		 *  -----------------------------------------------------------------------------------------------------*/

		private void button_traitement_Camera_Click(object sender, EventArgs e)
		{
			pictureBox1.Image = null;
			pt.type = listeGraine.Find(delegate(typeGraine g) { return g.nom == comboBoxTypeGraine.SelectedValue.ToString(); });

			if (textBoxNomFichier.Text == "")
			{
				MessageBox.Show("Le projet n'a pas de nom!");
				return;
			}
			Grabber g1 = new Grabber(); // s'occupe de la gestion des camera
			if (g1.partirCamera())
			{
				Image<Bgr, Byte> im2 = g1.RetourImage();
				imageInitiale = im2;
				im2.ROI = pt.Rinit;
				pt.ListeRecipientMatrice = definirContenantTest(im2.Copy());
				im2.Dispose();
				im2 = null;
				g1.arreterCamera();
			}

			accesibiliteButton(false, false, false, false, false, true, false, false);
			if (bwCamera.IsBusy != true) { bwCamera.RunWorkerAsync(pt); }
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  appel de la fonction assurant la gestion Thread  de partir camera
		 *  -----------------------------------------------------------------------------------------------------*/
		private void bw_DoWork_PartirCamera(object sender, DoWorkEventArgs e)
		{
			BackgroundWorker worker = sender as BackgroundWorker;
			ParamThread test = e.Argument as ParamThread;

			Grabber g = new Grabber(); // s'occupe de la gestion des camera
			if (g.partirCamera())
			{
				while (true)
				{
					if (worker.CancellationPending == false)
					{
						Image<Bgr, Byte> image = g.RetourImage();
						if (image != null)
						{
							List<Recipient> listeContenant = new List<Recipient>();
							image.ROI = test.Rinit;
							pt.ListeRecipientMatrice = definirContenantTest(image.Copy());
							GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, test.Rinit, HMinG.Value, HMaxG.Value, LMinG.Value, LMaxG.Value);
							List<Recipient> definirContenant = gc.CopierListe();
							gc.traitementTest();
							Image<Bgr, Byte> initiale2 = gc.dessinerTest(image);

							if (!checkBox1.Checked)
								initiale2.ROI = new Rectangle(0, 0, Settings.Default.camWidth, Settings.Default.camHeight);
							try
							{
								pictureBox1.Image = initiale2.Bitmap;
							}
							catch
							{
								System.Console.WriteLine("J'ai plante");
							}
						}
					}
					else
					{
						g.arreterCamera();
						break;

					}
				}
			}
			g = null;
		}


		/* -----------------------------------------------------------------------------------------------------
		*  appel de la fonction assurant la gestion du thread de partir video
		*  -----------------------------------------------------------------------------------------------------*/
		private void bw_DoWork_PartirVideo(object sender, DoWorkEventArgs e)
		{
			BackgroundWorker worker = sender as BackgroundWorker;
			ParamThread test = e.Argument as ParamThread;

			GrabberEMGU g = new GrabberEMGU(textBoxVid.Text); // s'occupe de la gestion des camera
			bool reponse = true;
			if (g.partirCamera())
			{
				while (reponse)
				{
					if (worker.CancellationPending == false)
					{
						Image<Bgr, Byte> image = g.RetourImage();
						if (image != null)
						{
							List<Recipient> listeContenant = new List<Recipient>();
							image.ROI = test.Rinit;
							pt.ListeRecipientMatrice = definirContenantTest(image.Copy());

							//GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, test.Rinit, HMinG.Value, HMaxG.Value, LMinG.Value, LMaxG.Value);
							GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, test.Rinit,pt.type);

							List<Recipient> definirContenant = gc.CopierListe();
							gc.traitementTest();
							Image<Bgr, Byte> initiale2 = gc.dessinerTest(image);

							if (!checkBox1.Checked)
								initiale2.ROI = new Rectangle(0, 0, Settings.Default.camWidth, Settings.Default.camHeight);
							try
							{
								Thread.Sleep(5);
								pictureBox1.Image = initiale2.Bitmap;
							}
							catch
							{
								System.Console.WriteLine("J'ai plante");
							}
						}
						else
						{
							g.arreterCamera();
							reponse = true;
							break;
						}
					}
					else
					{
						g.arreterCamera();
						break;
					}
				}
			}
			g = null;
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Fonction effectue lors de la ermeture du thread fr partir camera
		 *  -----------------------------------------------------------------------------------------------------*/
		private void bwPartirCamera_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Fonction effectue lors de la ermeture du thread fr partir video
		 *  -----------------------------------------------------------------------------------------------------*/
		private void bwPartirVideo_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Thread de la fonction assurant la gestion de la camera
		 *  -----------------------------------------------------------------------------------------------------*/
		private void bw_DoWork_Camera(object sender, DoWorkEventArgs e)
		{
			BackgroundWorker worker = sender as BackgroundWorker;
			ParamThread pt = e.Argument as ParamThread;

			// Image<Bgr, Byte> ImageBackground = new Image<Bgr, Byte>("background.bmp");
			Image<Bgr, Byte> ImageBackground = new Image<Bgr, Byte>("backgroundJPG.jpg");

			Image<Bgr, Byte> image = new Image<Bgr, Byte>("backgroundJPG.jpg");
			Image<Bgr, Byte> Previous_Frame = new Image<Bgr, Byte>("backgroundJPG.jpg");
			Image<Bgr, Byte> ImageCoul = new Image<Bgr, Byte>("matrice.jpg");

			Grabber g = new Grabber(); // s'occupe de la gestion des camera

			int numPlateau = 0;


			Rectangle ROIImageComplete = new Rectangle(ImageBackground.ROI.X, ImageBackground.ROI.Y, ImageBackground.ROI.Width, ImageBackground.ROI.Height);

			if (g.partirCamera())
			{
				while (true)
				{
					if (worker.CancellationPending == false)
					{
						bool traiter = false;
						bool avance = false;
						
						bool grilleEnPosition = false;
						bool grilleEnPositionAjuster = false;
						Rectangle grillePosition = new Rectangle(pt.Rinit.X, pt.Rinit.Y, pt.Rinit.Width, pt.Rinit.Height);


						int nombre = 0;

						List<Recipient> listeContenant = new List<Recipient>();
						int iteration = 0;
						initialiserListe();


						do //tant qu'il y a des iteration
						{
							if (worker.CancellationPending == true)
								break;
							try
							{
								Previous_Frame = ImageCoul; //background.jpg ????
								for (int j = 0; j < 5; j++)
								{
									if (worker.CancellationPending == true)
										break;
									image = g.RetourImage();
									
									if (image != null)
									{

										if (iteration == 0)
										{
											image.ROI = pt.Rinit;
											Previous_Frame.ROI = pt.Rinit;
										}
										else // iteration 1 2 3 4 5 
										{
											image.ROI = grillePosition;
											Previous_Frame.ROI = grillePosition;
										}



										if (j == 0)
											Previous_Frame.Bitmap = image.Bitmap;
										if (j == 4)
										{
											/****** affiche l'avancement dans la picturebox1 **********/
											try
											{
												Thread.Sleep(5);
												pictureBox1.Image = image.Bitmap;
											}
											catch
											{
												System.Console.WriteLine("J'ai plante");
											}
											/****************************************************************/

											ClasseDisposable verifierAvance = new ClasseDisposable(image, Previous_Frame);
	//voir a remmettre			//							avance = verifierAvance.verifierAvancement();
	// voir a remettre			//							verifierAvance.Dispose();

										  
											
											GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, pt.Rinit, pt.type);
										   
											if (avance && traiter) // permet d attendre le prochain 4X12 cellules
												traiter = false;

											if (!avance && iteration == 0 && !grilleEnPosition)
											{
												grillePosition = gc.PositionnerGrille(image, ImageBackground);
												//pictureBox1.Image = image.Bitmap;
												//   Thread.Sleep(5);


												if (grilleEnPosition = gc.GrillePositionner(pt.Rinit, grillePosition))
												{
													pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
													//  image.ROI = pt.Rinit;
													image.ROI = grillePosition;

													gc.changerRinit(grillePosition);
													//initialiserListe();
												}
											}

											
											if (!avance && !traiter && grilleEnPosition) // && grilleEnPosition
											{
												// Correction IMage
					 // 2104                  
												/* image.ROI = ROIImageComplete;
												Rectangle ROIACorriger = new Rectangle(0, grillePosition.Y - grillePosition.Height / 2, image.ROI.Width, grillePosition.Height + grillePosition.Height);
                                                    gc.corrigerImage(image, ROIImageComplete, ROIACorriger);
												gc.corrigerImage(image, ROIImageComplete, grillePosition);
		   // A ajouter Mai 2018				gc.corrigerIntensiteImage(image, ROIImageComplete, ROIACorriger);
												image.ROI = grillePosition;*/

					  //2104                         
											   /* if (iteration == 0) // ajouter 2804 voir si plateau 
												
												{
													grillePosition = gc.AjusterGrille(image);
													pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
													image.ROI = pt.Rinit;
													image.ROI = grillePosition;
													gc.changerRinit(grillePosition);
												}*/

												/* if (iteration == 0) // ajouter 2804 voir si plateau 
												 {
													 grillePosition = gc.AjusterGrilleVersLeHaut(image);
													 pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
													 image.ROI = pt.Rinit;
													 image.ROI = grillePosition;
													 gc.changerRinit(grillePosition);
												}
												else // iteration 1 2 3 4 5
												{
													 grillePosition = gc.AjusterGrilleVersLeBas(image);
													 pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
													 image.ROI = pt.Rinit;
													 image.ROI = grillePosition;
													 gc.changerRinit(grillePosition);
												}
												 
												 */


												//pictureBox1.Image = image.Bitmap;
												//   Thread.Sleep(25);

										  
							//2104                    
												// if (grilleEnPositionAjuster = gc.GrillePositionner(pt.Rinit, grillePosition))
												//{

												  //  pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
													//  image.ROI = pt.Rinit;
												   // image.ROI = grillePosition;
												   // gc.changerRinit(grillePosition);

													//initialiserListe();


												//}
												//grilleEnPositionAjuster = false;*/


												/*
												 * SP1.Write(...) //Alterne au visible
												 * image2 = g.RetourImage();
												 * SP1.Write(...) //Alterne à l'infrarouge
												 */

												nombre += gc.Traitement(image, /*image2,*/ matrice, 0, nombre);
												List<Recipient> definirContenant = gc.CopierListe();

												foreach (Recipient c in definirContenant)
													listeContenant.Add(new Recipient(c));
												definirContenant = null;
												traiter = true;
												if (iteration >= 5 && nombre == 288)
													iteration = 7;
												else
													iteration++;

												//Previous_Frame = image;
												try
												{
													Bitmap dessin = Set(gc.dessiner(image));
													dessin.Save("d:\\imagePartielle.gif", System.Drawing.Imaging.ImageFormat.Gif);
													if (iteration == 7)
													{
														
													   //dessin.Save("d:\\imageComplete"+numPlateau.ToString()+".gif", System.Drawing.Imaging.ImageFormat.Gif);
														dessin.Save("d:\\imageComplete.gif", System.Drawing.Imaging.ImageFormat.Gif);
														initialiserListe();
														numPlateau++; // ajouter pour compter le nombre de plateaux passes
													}
													dessin.Dispose();
													dessin = null;
												}
												catch
												{
													System.Console.WriteLine("J'ai plante");
												}
											}
											gc.Dispose();
											gc = null;
										}
										image.Dispose();
										image = null;
									}
								}
								if (iteration == 7)
								{
									try
									{

										Bd Bd1 = new Bd("|DataDirectory|\\BD\\BDGraine.mdb");
										Bd1.Open();
										List<string> s = new List<string> { DateTime.Today.ToString(), textBoxNomFichier.Text };
										int NoPLateau = Bd1.AjoutPlateau("Plateau", s);
										int nbRecipient = 0;
										foreach (Recipient c in listeContenant)
											Bd1.AjoutRecipient("Recipient", NoPLateau, c, ++nbRecipient);
										listeContenant.Clear();
										Bd1.Close();
										Bd1 = null;
									}
									catch
									{
										System.Console.WriteLine("J'ai plante en enregistrant");
									}
								}
							}
							catch
							{
								System.Console.WriteLine("J'ai plante");
							}
						} while (iteration != 7 && !worker.CancellationPending);
					}
					else
					{
						g.arreterCamera();
						break;
					}
				}
				g.arreterCamera();
			}
 
			// voir g.arreterCamera();
			g = null;

		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Thread de la fonction assurant la gestion du video
		 *  -----------------------------------------------------------------------------------------------------*/
		private void bw_DoWork_emgu(object sender, DoWorkEventArgs e)
		{
			 BackgroundWorker worker = sender as BackgroundWorker;
			GrabberEMGU g = new GrabberEMGU(textBoxVid.Text); // s'occupe de la gestion des camera
			//appel de la fonction assurant la gestion de l'image
			ParamThread pt = e.Argument as ParamThread;
			bool reponse = true;
			// Image<Bgr, Byte> ImageBackground = new Image<Bgr, Byte>("background.bmp");
		 
			Image<Bgr, Byte> ImageBackground = new Image<Bgr, Byte>("backgroundJPG.jpg"); // image courroie vide
			
			Image<Bgr, Byte> image = new Image<Bgr, Byte>("backgroundJPG.jpg"); 
			Image<Bgr, Byte> Previous_Frame = new Image<Bgr, Byte>("backgroundJPG.jpg");
			//Image<Bgr, Byte> ImageCoul = new Image<Bgr, Byte>("matrice.bmp");
            Image<Bgr, Byte> ImageCoul = new Image<Bgr, Byte>("backgroundJPG.jpg"); // image courroie vide

            int nbImagesMotion = 0;

            ImageBackground._SmoothGaussian(25);

            
            //pictureBox1.Image = ImageBackground.Bitmap;
            //Thread.Sleep(25);

			// Rectangle ROIImageComplete = new Rectangle(,,,);
			Rectangle ROIImageComplete = new Rectangle(ImageBackground.ROI.X, ImageBackground.ROI.Y, ImageBackground.ROI.Width, ImageBackground.ROI.Height);

			if (g.partirCamera())
			{
				while (reponse)
				{
					if (worker.CancellationPending == false)
					{
						bool traiter = false;
						bool avance = false;
			// bool grilleEnPosition = false;
						bool grilleEnPosition = false;
						bool grilleEnPositionAjuster = false;
						Rectangle grillePosition = new Rectangle(pt.Rinit.X, pt.Rinit.Y, pt.Rinit.Width, pt.Rinit.Height);

			
						int nombre = 0;

						//Image<Bgr, Byte> image, Previous_Frame; 
						
						// Ajouter dans Traitement cam

					   // Image<Bgr, Byte> ImageAccDiff;

						List<Recipient> listeContenant = new List<Recipient>();
						int iteration = 0;
						initialiserListe();
						do //tant qu'il y a des iterations
						{
							if (worker.CancellationPending == true)
							{
								reponse = false;
								break;
							}
							try
							{
							   // Previous_Frame = ImageCoul; // init de l'image precedente


								// ImageAccDiff = ImageCoul;
								//ImageAccDiff = ImageAccDiff.CopyBlank();
								//  ImageAccDiff.ROI = pt.Rinit;

								for (int j = 0; j < 5; j++) // 5<->10
								{

								   // ImageAccDiff = ImageAccDiff.CopyBlank();
								   
									if (worker.CancellationPending == true)
										break;
									image = g.RetourImage(); // capture d'images en continue
									if (image != null)
									{
					// if(iteration == 0) ou !grileEnPosition
										if (iteration == 0)
										{
											image.ROI = pt.Rinit;
											Previous_Frame.ROI = pt.Rinit;
                                            System.Console.WriteLine("NB Bloc de 5 frames en mouvement" + nbImagesMotion.ToString());
                                            nbImagesMotion = 0;
										}
										else // iteration 1 2 3 4 5 
										{
											image.ROI = grillePosition;
											Previous_Frame.ROI = grillePosition;
										}

										  
										if (j == 0) // debut de sequence de 5 frames
											Previous_Frame.Bitmap = image.Bitmap;


										if (j == 4) // 4<->9 // fin de sequence
										{

											/****** affiche l'avancement dans la picturebox1 **********/
											try
											{

											   
											 
                                              //pictureBox1.Image = Previous_Frame.Bitmap;
                                                //  Thread.Sleep(25);
                                       /*         image.ROI = ROIImageComplete;
                                                pictureBox1.Image = image.Bitmap;
                                                Thread.Sleep(5);
                                                if(iteration > 0)
                                                    image.ROI = grillePosition;
                                                else
                                                    image.ROI = pt.Rinit;*/
											}
											catch
											{
						   
												System.Console.WriteLine("Probleme lors de la lecture d'image");
											}
											/****************************************************************/

										   ClasseDisposable verifierAvance = new ClasseDisposable(image, Previous_Frame);

										   // ClasseDisposable verifierAvance = new ClasseDisposable(image, ImageAccDiff);

										   // if (verifierAvance.DetecterDebutPlateau(image, ImageBackground)) // verifier la presente du debut d un plateau
										   // {
											//    Thread.Sleep(5);
											//    pictureBox1.Image = image.Bitmap;

												avance = verifierAvance.verifierAvancement();

                                                
                                                /*Image<Bgr, Byte> Imdiff = verifierAvance.verifierAvancement();

                                                pictureBox1.Image = Imdiff.Bitmap;
                                                Thread.Sleep(25);*/


												// avance = verifierAvance.verifierAvancementBlur();
											   // avance = verifierAvance.verifierAvancementBlob();
												//avance = verifierAvance.verifierAvancementSharpness();

                                                //GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, pt.Rinit, pt.type);

											    /*if (verifierAvance.DetecterDebutPlateau(image, ImageBackground) && !avance) // verifier la presente du debut d un plateau
												{
													Image<Gray, Single> imS = image.Convert<Gray,Single>();
													Image<Gray, Single> imG = imS.Sobel(0,2,3);
													Image<Gray, Byte> imGGray =imG.Convert<Gray,byte>();
                                                    Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, ImageBackground);
													Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, ImageBackgroundGray);
													pictureBox1.Image = imGGray.Bitmap;
                                                    pictureBox1.Image = image.Bitmap;
													Thread.Sleep(25);

													//verifierAvance.verifierAvancementMotionBlur(50);
												}*/


												verifierAvance.Dispose();

   

										  

											    GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, pt.Rinit, pt.type);

                                             
												if (avance && traiter)
													traiter = false;

                                                if(avance && iteration > 0)
                                                    nbImagesMotion++;


                                             
										/*		  if (!avance)
												  {
                                                     // Image<Gray, Byte> imG = image.Convert<Gray, Byte>();
                                                     // Image<Gray, Byte> imPF = Previous_Frame.Convert<Gray, Byte>();
                                                     // Image<Gray, Byte> imDIFF = imG.AbsDiff(imPF);

                                                      //image.ROI = ROIImageComplete;
                                                      //Image<Bgr, Byte> imDIFF = image.AbsDiff(Previous_Frame);
                                                      //Image<Bgr, Byte> imDIFF2 = imDIFF.InRange(new Bgr(0, 0, 0), new Bgr(255, 255, 255));
                                                      //pictureBox1.Image = imDIFF.Bitmap;
                                                      //Thread.Sleep(25);
                                                      //image.ROI = pt.Rinit;
                                                     // Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, Previous_Frame);
                                                     Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, ImageBackground);
													  //Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, ImageBackgroundGray);
													 pictureBox1.Image = imDIFF.Bitmap;
													  Thread.Sleep(25);
												  } */

												if (!avance && iteration == 0 && !grilleEnPosition)
												{
													

													grillePosition = gc.PositionnerGrille(image, ImageBackground);


													if (grilleEnPosition = gc.GrillePositionner(pt.Rinit, grillePosition))
													{
														pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
														//  image.ROI = pt.Rinit;
														image.ROI = grillePosition;
														gc.changerRinit(grillePosition);

                                                   /*     image.ROI = ROIImageComplete;
                                                       // image.Draw(grillePosition, new Bgr(Color.Green), 2);
                                                        pictureBox1.Image = image.Bitmap;
                                                        Thread.Sleep(5);
                                                        image.ROI = grillePosition; */
													}
												}


												if (!avance && !traiter && grilleEnPosition) // AJOUTER DUREE DU DEPLACEMENT
												{
                                                   /* image.ROI = ROIImageComplete;
                                                    Rectangle ROIACorriger = new Rectangle(0, grillePosition.Y - grillePosition.Height / 2, image.ROI.Width, grillePosition.Height + grillePosition.Height);
                                                    gc.corrigerImage(image, ROIImageComplete, ROIACorriger);
									// A ajouter Mai 2018				gc.corrigerIntensiteImage(image, ROIImageComplete, ROIACorriger);
                                                    image.ROI = grillePosition;*/
                                                    if(iteration == 0)
												        grillePosition = gc.AjusterGrille2(image, iteration);

                                                            image.ROI = ROIImageComplete;
                                                            image.Draw(grillePosition, new Bgr(Color.Green), 2);
                                                            pictureBox1.Image = image.Bitmap;
                                                            Thread.Sleep(5);
                                                            image.ROI = grillePosition; 



                           
                                                    pt.changerRinit(grillePosition.X, grillePosition.Y, grillePosition.Width, grillePosition.Height);
                                                    //image.ROI = pt.Rinit;
                                                    image.ROI = grillePosition;
                                                    gc.changerRinit(grillePosition); 
	                                    
												  /*  Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, ImageBackground);
													//Image<Gray, Byte> imDIFF = gc.dessinerDiff(image, ImageBackgroundGray);
													Image<Gray, Byte> imDIFFT = imDIFF.ThresholdBinary(new Gray(100), new Gray(255));
													//imDIFFT.Not();
													Image<Gray, Byte> imDIFFINR = imDIFF.InRange(new Gray(100), new Gray(110));
													pictureBox1.Image = imDIFFINR.Bitmap;
													Thread.Sleep(25);*/

													//image.ROI = grillePosition;
													nombre += gc.Traitement(image, matrice, 0, nombre);
												   

													List<Recipient> definirContenant = gc.CopierListe();

													foreach (Recipient c in definirContenant)
														listeContenant.Add(new Recipient(c));

													definirContenant = null;
													traiter = true;
													if (iteration >= 5 && nombre == 288)
														iteration = 7;
													else
														iteration++;

											  // ????      Previous_Frame = image;
													try
													{

														Bitmap dessin = Set(gc.dessiner(image)); // ?????????????????
													
	                                                    // d:\\
														dessin.Save("d:\\imagePartielle.gif", System.Drawing.Imaging.ImageFormat.Gif);
														if (iteration == 7)
														{
                                                            // d:\\
															dessin.Save("d:\\imageComplete.gif", System.Drawing.Imaging.ImageFormat.Gif);
															initialiserListe();
														}
														dessin.Dispose();
														dessin = null;
													}
													catch(Exception err)
													{
														System.Console.WriteLine("Probleme de sauvegarde et de dessin Image Partielle et Complete");
													}
												}
												gc.Dispose(); // ?????????????
												gc = null;

										   // }
										   // else
											//    verifierAvance.Dispose();

										}
										image.Dispose();
										image = null;
									}
									else
									{
										reponse = false;
										break;
									}
								}
								
								if (iteration == 7) // == 1 si on veut garder que le premier 4X12
								{
									try
									{

										Bd Bd1 = new Bd("|DataDirectory|\\BD\\BDGraine.mdb");
										Bd1.Open();
										List<string> s = new List<string> { DateTime.Today.ToString(), textBoxNomFichier.Text };
										int NoPLateau = Bd1.AjoutPlateau("Plateau", s);
										int nbRecipient = 0;
										foreach (Recipient c in listeContenant)
											Bd1.AjoutRecipient("Recipient", NoPLateau, c, ++nbRecipient);
										listeContenant.Clear();
										Bd1.Close();
										Bd1 = null;
									}
									catch
									{
										System.Console.WriteLine("Probleme en enregistrant");
									}
								}
							}
							catch
							{
								System.Console.WriteLine("Probleme de lecture du video");
							}
						} while (iteration != 7 && reponse && !worker.CancellationPending);
					}
					else
					{
						g.arreterCamera();
						break;
					}
				}
				g.arreterCamera();
			}
			g = null;
		}

        public Image<Gray, Byte> dessinerDiffLocal(Image<Bgr, Byte> image, Image<Bgr, Byte> back)
        {

            Rectangle r = new Rectangle(image.ROI.X, image.ROI.Y, image.ROI.Width, image.ROI.Height);
            image.ROI = new Rectangle(0, 0, Settings.Default.camWidth, Settings.Default.camHeight);

            Image<Bgr, Byte> Difference = image.AbsDiff(back);


            //Image<Gray, Byte> DifferenceGray = Difference.Convert<Gray, Byte>();

            Image<Gray, Byte> DifferenceGray = Difference.InRange(new Bgr(0, 0, 0), new Bgr(255, 255, 255));

            image.ROI = r;

            return DifferenceGray;

        }



		/* -----------------------------------------------------------------------------------------------------
		 *  Initialisation de la liste de traitement
		 *  -----------------------------------------------------------------------------------------------------*/
		private void initialiserListe()
		{
			pt.EffacerList();
			Image<Bgr, Byte> image = new Image<Bgr, byte>("test.jpg");
			image.ROI = pt.Rinit;
			image = image.Resize(0.25, Emgu.CV.CvEnum.INTER.CV_INTER_AREA);
			image = image.Flip(Emgu.CV.CvEnum.FLIP.VERTICAL);
			image = image.CopyBlank();
			Image<Bgr, Byte> imageNoir = image.CopyBlank();
			for (int i = 0; i < 6; i++)
			{
				imageNoir = imageNoir.ConcateVertical(imageNoir);
				pt.AjouterImageList(image.CopyBlank());
			}
			image.Dispose();
			image = null;
			imageNoir.Dispose();
			imageNoir = null;
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  gestion de la liste de traitement
		 *  -----------------------------------------------------------------------------------------------------*/
  /*      public Bitmap Set(Image<Bgr, Byte> image)
		{
			if (image != null)
			{
				pt.EffacerImageList();
				image = image.Resize(0.25, Emgu.CV.CvEnum.INTER.CV_INTER_AREA);
				pt.AjouterImageList
					(image.Copy());
		 
			   Image<Bgr, Byte> imageGeneralAss = image;
				for (int i = 6 - 2; i >= 0; i--)
					imageGeneralAss = imageGeneralAss.ConcateVertical(pt.RetournerImageList(i));

				imageGeneralAss = imageGeneralAss.Rotate(90, new Bgr(Color.Blue), false);
				Bitmap bit = imageGeneralAss.Bitmap;
				imageGeneralAss.Dispose();
				imageGeneralAss = null;
				image.Dispose();
				image = null;
				return bit;
			}
			return null;
		}*/



		/* -----------------------------------------------------------------------------------------------------
		 *  gestion de la liste de traitement
		 *  -----------------------------------------------------------------------------------------------------*/
		public Bitmap Set(Image<Bgr, Byte> image)
		{
			if (image != null)
			{
				pt.EffacerImageList();
				pt.AjouterImageList(image.Copy());
				Image<Bgr, Byte> imageGeneralAss = null;
				for (int i = 0; i <= 5; i++)
					imageGeneralAss = imageGeneralAss == null ? pt.RetournerImageList(i) : imageGeneralAss.ConcateHorizontal(pt.RetournerImageList(i));
				Bitmap bit = imageGeneralAss.Bitmap;
				imageGeneralAss.Dispose();
				imageGeneralAss = null;
				image.Dispose();
				image = null;
				return bit;
			}
			return null;
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Impression Rapport base de donnee locale
		 *  -----------------------------------------------------------------------------------------------------*/
		private void buttonImprimerLocal_Click(object sender, EventArgs e)

			{
				Bd Bd1 = new Bd("|DataDirectory|\\BD\\BDGraine.mdb");
				System.Data.DataTable Table, Table2;
				Table = Bd1.Rechercher("Plateau");
				List<ClassRapport> lc = new List<ClassRapport>();
				List<string> donnee = new List<string>();
				for (int i = 0; i < Table.Rows.Count; i++)
				{
					List<RecipientRapport> lr = new List<RecipientRapport>();
					int s = int.Parse(Table.Rows[i][0].ToString());
					DateTime d = DateTime.Parse(Table.Rows[i][1].ToString());
					string  noProjet = Table.Rows[i][2].ToString();
					Table2 = Bd1.Rechercher("Recipient", s);
					if (Table2.Rows.Count > 0)
						for (int j = 0; j < Table2.Rows.Count; j++)
							lr.Add(new RecipientRapport(int.Parse(Table2.Rows[j][1].ToString()), int.Parse(Table2.Rows[j][2].ToString())));

					lc.Add(new ClassRapport(lr,s,noProjet,d));
				}

				FRapport f = new FRapport();
				f.setDatasourceRapport("Report1");
				f.bindingSourceRapport.DataSource = lc;
				f.ShowDialog();
			}

		/* -----------------------------------------------------------------------------------------------------
		 *  Impression avancee Rapport base de donnee locale
		 *  -----------------------------------------------------------------------------------------------------*/
		private void buttonImprimerAvanceeLocal_Click(object sender, EventArgs e)
		{
			DemandeRapport dr = new DemandeRapport();  
			dr.Show();
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Impression Rapport base de donnee serveur
		 *  -----------------------------------------------------------------------------------------------------*/
		private void buttonEnregistrementServeur_Click(object sender, EventArgs e)
		{
			if (bw.IsBusy != true) { bw.RunWorkerAsync(); }
			Bd Bd1 = new Bd("|DataDirectory|\\BD\\BDGraine.mdb");
			Bd Bd2 = new Bd("|DataDirectory|\\BDServeur\\BDGraine.mdb");
			Bd2.ouvrirCopie();
			System.Data.DataTable Table, Table2;
			Table = Bd1.Rechercher("Plateau");
			for (int i = 0; i < Table.Rows.Count; i++)
			{
			   Bd2.copiePlateau("Plateau", new List<string> { Table.Rows[i][0].ToString(), Table.Rows[i][1].ToString(), Table.Rows[i][2].ToString() });
			   increment = i;
			   nomAttente = "enregistrement Plateau en cours..." + increment.ToString() + " sur " + maxIncrement.ToString() + "...";
			}
			Bd1.Effacer("Plateau");
			Table2 = Bd1.Rechercher("Recipient");
			maxIncrement = Table2.Rows.Count;
			for (int i = 0; i < Table2.Rows.Count; i++)
			{
			   Bd2.copieRecipient("Recipient", new List<string> { Table2.Rows[i][0].ToString(), Table2.Rows[i][1].ToString(), Table2.Rows[i][2].ToString() });
			   increment = i;
			   nomAttente = "enregistrement recipient en cours..." + increment.ToString() + " sur " + maxIncrement.ToString() + "...";
			}
			Bd2.Dispose();
			Bd1.Effacer("Recipient");
			if (bw.WorkerSupportsCancellation == true) { bw.CancelAsync(); }
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Thread appelant la Fenêtre d'attente
		 *  -----------------------------------------------------------------------------------------------------*/

		private void bw_DoWork(object sender, DoWorkEventArgs e)
		{
			BackgroundWorker worker = sender as BackgroundWorker;
			MessageAttente messageAttente = new MessageAttente();
			messageAttente.Marque.Maximum = 6000;
			messageAttente.Show();
			while (true)
			{
				if (worker.CancellationPending == false)
				{
					messageAttente.MessageLabel.Text = nomAttente;
					messageAttente.Marque.Maximum = maxIncrement;
					messageAttente.Marque.Value = (increment < messageAttente.Marque.Maximum ? increment : messageAttente.Marque.Maximum);
					messageAttente.Refresh();
				}
				else
				{
					messageAttente.Close();
					break;
				}
			}
		}

		/* -----------------------------------------------------------------------------------------------------
		 *  Rapport de la liste du serveur
		 *  -----------------------------------------------------------------------------------------------------*/

		private void buttonImprimerServeur_Click(object sender, EventArgs e)
		{
			Bd Bd1 = new Bd("|DataDirectory|\\BDServeur\\BDGraine.mdb");
			System.Data.DataTable Table, Table2;
			Table = Bd1.Rechercher("Plateau");
			List<ClassRapport> lc = new List<ClassRapport>();
			List<string> donnee = new List<string>();
			for (int i = 0; i < Table.Rows.Count; i++)
			{
				List<RecipientRapport> lr = new List<RecipientRapport>();
				int s = int.Parse(Table.Rows[i][0].ToString());
				DateTime d = DateTime.Parse(Table.Rows[i][1].ToString());
				string noProjet = Table.Rows[i][2].ToString();
				Table2 = Bd1.Rechercher("Recipient", s);
				if (Table2.Rows.Count > 0)
					for (int j = 0; j < Table2.Rows.Count; j++)
						lr.Add(new RecipientRapport(int.Parse(Table2.Rows[j][1].ToString()), int.Parse(Table2.Rows[j][2].ToString())));

				lc.Add(new ClassRapport(lr, s, noProjet, d));
			}

			FRapport f = new FRapport();
			f.setDatasourceRapport("Report1");
			f.bindingSourceRapport.DataSource = lc;
			f.ShowDialog();
		}



		/* -----------------------------------------------------------------------------------------------------
		*  Lecture de repertoire pour un fichier video
		*  -----------------------------------------------------------------------------------------------------*/
		private void button3_Click(object sender, EventArgs e)
		{
			OpenFileDialog ofd = new OpenFileDialog();
			ofd.Title = "Ouvrir un fichier de type AVI";
			ofd.InitialDirectory = Environment.CurrentDirectory;
			ofd.Filter = "Fichiers avi(*.avi) | *.avi;*.wmv";
			if (ofd.ShowDialog() == DialogResult.OK)
			{
				textBoxVid.Text = ofd.FileName; 
			}
			else
				MessageBox.Show("Vous n'avez pas choisi");
		}



		/* -----------------------------------------------------------------------------------------------------
		 *  Fonction gerant l'accesibilite des different bouton
		 *  -----------------------------------------------------------------------------------------------------*/
		private void accesibiliteButton(bool partirCam, bool arreterCam, bool PartirVideo, bool arreterVideo, bool traitementCam, bool arreterTraitementCam, bool traiterVideo, bool arreterTraitementVideo)
		{
			bouttonPartirCam.Enabled = partirCam;
			buttonArreterCam.Enabled = arreterCam;

			buttonPartirVideo.Enabled = PartirVideo;
			buttonArreterVideo.Enabled = arreterVideo;

			buttonTraiterVideo.Enabled = traiterVideo;
			buttonQuitterVideo.Enabled = arreterTraitementVideo;

			buttonTraitementCam.Enabled = traitementCam;
			buttonQuitterCam.Enabled = arreterTraitementCam;


		}



		/* -----------------------------------------------------------------------------------------------------
		 *  Fonction executer a l'arret du thread de l'arret  de la camera
		 *  -----------------------------------------------------------------------------------------------------*/
		private void buttonArreterCam_Click(object sender, EventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
			if (bwPartirCam.WorkerSupportsCancellation == true) { bwPartirCam.CancelAsync(); }   
		}

		private void buttonArreterVideo_Click(object sender, EventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
			if (bwPartirVideo.WorkerSupportsCancellation == true) { bwPartirVideo.CancelAsync(); }   
		}
		private void buttonQuitterVideo_Click(object sender, EventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
			if (bwEMGU.WorkerSupportsCancellation == true) { bwEMGU.CancelAsync(); }
		}

		private void bwEMGU_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
			pt.changerRinit((int)ValX.Value, (int)ValY.Value, (int)ValH.Value, (int)ValW.Value); // inverser ValH et ValW ?????????????
		}

		private void buttonQuitterCam_Click(object sender, EventArgs e)
		{
			accesibiliteButton(true, false, true, false, true, false, true, false);
		}




		/* -----------------------------------------------------------------------------------------------------
		 *  Fonction allant chercher une seule image du video
		 *  -----------------------------------------------------------------------------------------------------*/
		private void buttonPartirTest_Click(object sender, EventArgs e)
		{
			pictureBox1.Image = null;
			//Grabber g1 = new Grabber(); // s'occupe de la gestion des camera
			GrabberEMGU g1 = new GrabberEMGU(textBoxVid.Text); // s'occupe de la gestion des camera
			if (g1.partirCamera())
			{
				List<Recipient> listeContenant = new List<Recipient>();
				Image<Bgr, Byte> image = g1.RetourImage();
				image.ROI = pt.Rinit;
				pictureBox1.Image = image.Bitmap;
				pt.ListeRecipientMatrice = definirContenantTest(image.Copy());

				GestionCam gc = new GestionCam(pt.ListeRecipientMatrice, pt.Rinit, HMinG.Value, HMaxG.Value, LMinG.Value, LMaxG.Value);
				List<Recipient> definirContenant = gc.CopierListe();
				gc.traitementTest();

				Image<Bgr, Byte> initiale2 = gc.dessinerTest(image);
				if(!checkBox1.Checked)       
					  initiale2.ROI = new Rectangle(0, 0, Properties.Settings.Default.camWidth, Properties.Settings.Default.camHeight);
				pictureBox1.Image = initiale2.Bitmap;
				g1.arreterCamera();
			}
		}


		/* -----------------------------------------------------------------------------------------------------
		*  Fonction ajustant le ROI
		*  -----------------------------------------------------------------------------------------------------*/
		private void buttonAjusterROI_Click(object sender, EventArgs e)
		{
			pt.changerRinit((int)ValX.Value, (int)ValY.Value, (int)ValH.Value, (int)ValW.Value);
		}


		private void bas_ValueChanged(object sender, EventArgs e)
		{
			NumericUpDown i = sender as NumericUpDown;
			pt.changerRinit((int)ValX.Value, (int)ValY.Value ,(int)ValH.Value, (int)i.Value);
		}

		private void droite_ValueChanged(object sender, EventArgs e)
		{
			NumericUpDown i = sender as NumericUpDown;
			pt.changerRinit((int)ValX.Value, (int)ValY.Value, (int)i.Value, (int)ValW.Value);

		}

		private void haut_ValueChanged(object sender, EventArgs e)
		{
			NumericUpDown i = sender as NumericUpDown;
			pt.changerRinit((int)ValX.Value, (int)i.Value, (int)ValH.Value,(int)ValW.Value);
		}

		private void gauche_ValueChanged(object sender, EventArgs e)
		{
			NumericUpDown i = sender as NumericUpDown;
			pt.changerRinit((int)i.Value, (int)ValY.Value,  (int)ValH.Value,(int)ValW.Value);
		}


		/* -----------------------------------------------------------------------------------------------------
		 *  Enregistrement des options
		 *  -----------------------------------------------------------------------------------------------------*/

		private void buttonSauvegardeOption_Click(object sender, EventArgs e)
		{
			Settings.Default.gauche = int.Parse(ValX.Text);
			Settings.Default.droit = int.Parse(ValH.Text);
			Settings.Default.haut = int.Parse(ValY.Text);
			Settings.Default.bas = int.Parse(ValW.Text);
			Settings.Default.hauteurMinGraine = int.Parse(HMinG.Text);
			Settings.Default.hauteurMaxGraine = int.Parse(HMaxG.Text);
			Settings.Default.largeurMinGraine = int.Parse(LMinG.Text);
			Settings.Default.largeurMaxGraine = int.Parse(LMaxG.Text);
			Settings.Default.Save();
		}

		private void comboBoxTypeGraine_SelectedIndexChanged(object sender, EventArgs e)
		{
			typeGraine t = listeGraine.Find(delegate(typeGraine g) { return g.nom == comboBoxTypeGraine.SelectedValue.ToString(); });
			if (t == null) return;
			LMinG.Value = t.largeurMin;
			LMaxG.Value = t.largeurMax;
			HMinG.Value = t.hauteurMin;
			HMaxG.Value = t.hauteurMax;
		}

		private void SystemeDetection_Load(object sender, EventArgs e)
		{
			Bd Bd1 = new Bd("|DataDirectory|\\BD\\BDGraine.mdb");
			DataTable TableTypeGraine = Bd1.Rechercher("typeGraine");
			foreach (DataRow r in TableTypeGraine.Rows)
				listeGraine.Add(new typeGraine((string)r[1], (int)r[2], (int)r[3], (int)r[4], (int)r[5], (float)r[6], (int)r[7], (int)r[8], (float)r[9], (int)r[10]));

			/******  Liste combo   *******/
			comboBoxTypeGraine.DataSource = listeGraine.ToArray();
			comboBoxTypeGraine.DisplayMember = "Nom";
			comboBoxTypeGraine.ValueMember = "Nom";
			typeGraine t = listeGraine.Find(delegate(typeGraine g) { return g.nom == comboBoxTypeGraine.SelectedValue.ToString(); });
			LMinG.Value = t.largeurMin;
			LMaxG.Value = t.largeurMax;
			HMinG.Value = t.hauteurMin;
			HMaxG.Value = t.hauteurMax;
		}

		private void button1_Click(object sender, EventArgs e) // calcul des facteurs de correction K1 et K2
		{
  
			MotPasse motPasseDialog = new MotPasse();

			if (motPasseDialog.ShowDialog(this) == DialogResult.OK)
			{
				string value = motPasseDialog.ReturnValue;
                
				if (value.Equals(Settings.Default.motPasse))
				{
					Grabber g = new Grabber();

					if (g.partirCamera())
					{

                        Image<Bgr, Byte> imageDamier = new Image<Bgr, byte>("damier8X10.jpg");
						//Image<Bgr, byte> imageDamier = g.RetourImage();
						try
						{
							GestionCam.FacteurCorrection(imageDamier);
						}
						catch (Exception err)
						{
							MessageBox.Show("Impossible de determiner les facteurs de correction : \n" +
											err.Message,
								"Erreur !",
								MessageBoxButtons.OK,
								MessageBoxIcon.Exclamation,
								MessageBoxDefaultButton.Button1);
						}

					}

				}
				else
				{
					MessageBox.Show("Mot de passe invalide",
									"Erreur !",
									MessageBoxButtons.OK,
									MessageBoxIcon.Exclamation,
									MessageBoxDefaultButton.Button1);
				}
			}

		}
	}

}
